@@ -100,12 +100,10 @@ static void setup_pvip_const() {
     PConst(PVIP_NODE_TRY);
     PConst(PVIP_NODE_REF);
     PConst(PVIP_NODE_MULTI);
-    PConst(PVIP_NODE_LANG);
     PConst(PVIP_NODE_UNARY_BOOLEAN);
     PConst(PVIP_NODE_UNARY_UPTO);
     PConst(PVIP_NODE_STDOUT);
     PConst(PVIP_NODE_STDERR);
-    PConst(PVIP_NODE_INFINITY);
     PConst(PVIP_NODE_SCALAR_DEREF);
     PConst(PVIP_NODE_TW_INC);
     PConst(PVIP_NODE_META_METHOD_CALL);
@@ -155,6 +153,11 @@ static void setup_pvip_const() {
     PConst(PVIP_NODE_BITWISE_XOR);
     PConst(PVIP_NODE_VARGS);
     PConst(PVIP_NODE_WHATEVER);
+    PConst(PVIP_NODE_TW_ENV);
+    PConst(PVIP_NODE_ARRAY_DEREF);
+    PConst(PVIP_NODE_RAND);
+    PConst(PVIP_NODE_END);
+    PConst(PVIP_NODE_BEGIN);
     PConst(PVIP_CATEGORY_UNKNOWN);
     PConst(PVIP_CATEGORY_STRING);
     PConst(PVIP_CATEGORY_INT);
